@@ -6,7 +6,10 @@ from __future__ import absolute_import
 from pulpcore.client.pulp_container.api.content_blobs_api import ContentBlobsApi
 from pulpcore.client.pulp_container.api.content_manifests_api import ContentManifestsApi
 from pulpcore.client.pulp_container.api.content_tags_api import ContentTagsApi
+from pulpcore.client.pulp_container.api.contentguards_content_redirect_api import ContentguardsContentRedirectApi
 from pulpcore.client.pulp_container.api.distributions_container_api import DistributionsContainerApi
 from pulpcore.client.pulp_container.api.remotes_container_api import RemotesContainerApi
 from pulpcore.client.pulp_container.api.repositories_container_api import RepositoriesContainerApi
+from pulpcore.client.pulp_container.api.repositories_container_push_api import RepositoriesContainerPushApi
 from pulpcore.client.pulp_container.api.repositories_container_versions_api import RepositoriesContainerVersionsApi
+from pulpcore.client.pulp_container.api.token_api import TokenApi
